/*
 *   @(#) $Id: MessageEncoder.java 350169 2005-12-01 05:17:41Z trustin $
 *
 *   Copyright 2004 The Apache Software Foundation
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package org.apache.mina.filter.codec.demux;

import java.util.Set;

import org.apache.mina.common.ByteBuffer;
import org.apache.mina.common.IoSession;
import org.apache.mina.filter.codec.ProtocolEncoderOutput;

/**
 * Encodes messages of specific types specified by {@link #getMessageTypes()}.
 * 
 * @author The Apache Directory Project (dev@directory.apache.org)
 * @version $Rev: 350169 $, $Date: 2005-12-01 14:17:41 +0900 (Thu, 01 Dec 2005) $
 * 
 * @see DemuxingProtocolCodecFactory
 * @see MessageEncoderFactory
 */
public interface MessageEncoder
{  
    /**
     * Returns the set of message classes this encoder can encode.
     */
    Set getMessageTypes();

    /**
     * Encodes higher-level message objects into binary or protocol-specific data.
     * MINA invokes {@link #encode(IoSession, Object, ProtocolEncoderOutput)}
     * method with message which is popped from the session write queue, and then
     * the encoder implementation puts encoded {@link ByteBuffer}s into
     * {@link ProtocolEncoderOutput}.
     * 
     * @throws Exception if the message violated protocol specification
     */
    void encode( IoSession session, Object message,
                 ProtocolEncoderOutput out ) throws Exception;
}
